@@ -1,7 +1,7 @@
-"""Exceptions of the PPP Core."""
+"""Exceptions of the PPP modules."""
 
 class ClientError(Exception):
-    """Exception raised by the router for showing an error to the
+    """Exception raised by the module for showing an error to the
     client."""
     pass
 
